NAME

Boilerplater::Type::Integer - A primitive Type representing an integer.

DESCRIPTION

Boilerplater::Type::Integer holds integer types of various widths and various styles. A few standard C integer types are supported:

char
short
int
long
size_t

Many others are not: the types from "inttypes.h", "signed" or "unsigned" anything, "long long", "ptrdiff_t", "off_t", etc.

Instead, the following Charmonizer typedefs are supported:

bool_t
i8_t
i16_t
i32_t
i64_t
u8_t
u16_t
u32_t
u64_t

METHODS

new

my $type = Boilerplater::Type::Integer->new(
    const     => 1,       # default: undef
    specifier => 'char',  # required
);
  • const - Should be true if the type is const.

  • specifier - Must match one of the supported types.

COPYRIGHT AND LICENSE

Copyright 2008-2009 Marvin Humphrey

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.